@@ -12,13 +12,12 @@ There are a multitude of heap and heap-like modules on CPAN, you might
 want to search for /Heap/ and /Priority/ to find many. They implement more
 or less fancy datastructures that might well be what you are looking for.
 
-This module takes a different approach: It exports functions (i.e. not
+This module takes a different approach: It exports functions (i.e. no
 object orientation) that are loosely modeled after the C++ STL's heap
 functions. They all take an array as argument, just like perl's built-in
 functions C<push>, C<pop> etc.
 
-The implementation itself is in C for maximum speed (although I doubt it
-makes that much of a difference).
+The implementation itself is in C for maximum speed.
 
 =head1 FUNCTIONS
 
@@ -31,15 +30,21 @@ All of the following functions are being exported by default.
 package Array::Heap;
 
 BEGIN {
-   $VERSION = '1.3';
+   $VERSION = '2.0';
 
    require XSLoader;
-   XSLoader::load Array::Heap, $VERSION;
+   XSLoader::load ("Array::Heap", $VERSION);
 }
 
 use base Exporter;
 
-@EXPORT = qw(make_heap make_heap_lex make_heap_cmp push_heap push_heap_lex push_heap_cmp pop_heap pop_heap_lex pop_heap_cmp);
+@EXPORT = qw(
+   make_heap   make_heap_lex   make_heap_cmp
+   push_heap   push_heap_lex   push_heap_cmp
+   pop_heap    pop_heap_lex    pop_heap_cmp
+   splice_heap splice_heap_lex splice_heap_cmp
+   adjust_heap adjust_heap_lex adjust_heap_cmp
+);
 
 =item make_heap @heap                                   (\@)
 
@@ -81,6 +86,35 @@ comparison order.
 
 Just like C<pop_heap>, but takes a custom comparison function.
 
+=item splice_heap @heap, $index                         (\@$)
+
+Similar to C<pop_heap>, but removes and returns the element at index
+C<$index>.
+
+=item splice_heap_lex @heap, $index                     (\@$)
+
+Just like C<splice_heap>, but in string comparison order instead of
+numerical comparison order.
+
+=item splice_heap_cmp { compare } @heap, $index         (&\@$)
+
+Just like C<splice_heap>, but takes a custom comparison function.
+
+=item adjust_heap @heap, $index                         (\@$)
+
+Assuming you have only changed the element at index C<$index>, repair the
+heap again. Can be used to remove elements, replace elements, adjust the
+priority of elements and more.
+
+=item adjust_heap_lex @heap, $index                     (\@$)
+
+Just like C<adjust_heap>, but in string comparison order instead of
+numerical comparison order.
+
+=item adjust_heap_cmp { compare } @heap, $index         (&\@$)
+
+Just like C<adjust_heap>, but takes a custom comparison function.
+
 =cut
 
 1;
@@ -107,7 +141,9 @@ will sort according to the first element of the arrays, i.e. C<1,2,3>.
 
 The custom comparison functions work similar to how C<sort> works: C<$a>
 and C<$b> are set to the elements to be compared, and the result should be
-either C<-1> if C<$a> is less than C<$b>, or C<< >= 0 >> otherwise.
+greater than zero then $a is greater than $b, C<0> otherwise. This means
+that you cna use the same function as for sorting the array, but you could
+also use a simpler function that just does C<< $a > $b >>.
 
 The first example above corresponds to this comparison "function":
 
@@ -122,7 +158,23 @@ use normal subroutines.
 
 =head1 BUGS
 
-This module works not work with tied or magical arrays or array elements.
+=over 4
+
+=item * Numerical comparison is always done using floatingpoint, which
+usually has less precision than a 64 bit integer that perl might use
+for integers internally, resulting in precision loss on the built-in
+comparison.
+
+=item * This module does not work with tied or magical arrays or array
+elements, and, in fact, will even crash when you use those.
+
+=item * This module can leak memory (or worse) when your comparison
+function exits unexpectedly (e.g. C<last>) or throws an exception, so do
+not do that.
+
+=back
+
+=cut
 
 =head1 AUTHOR
 
